@@ -3,6 +3,7 @@ package DB::Berkeley;
 use strict;
 use warnings;
 
+use Exporter 'import';
 require XSLoader;
 
 =head1 NAME
@@ -11,11 +12,16 @@ DB::Berkeley - XS-based OO Berkeley DB HASH interface
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
+our @EXPORT_OK = qw(DB_RDONLY);
+use constant DB_RDONLY => 0x00000400;	# Must be the same as in db.h
+
+XSLoader::load('DB::Berkeley', $VERSION);
 
 =head1 DESCRIPTION
 
@@ -69,6 +75,13 @@ DB_File works, I just prefer this API.
 
 =head1 METHODS
 
+=head2 new
+
+    my $db = DB::Berkeley->new($filename, $flags, $mode, $sync_on_put);
+
+Creates and opens a new Berkeley DB file.
+If C<$sync_on_put> is true, every C<put()> will automatically call C<sync()> to flush to disk.
+
 =head2 store($key, $value)
 
 Alias for C<put>. Stores a key-value pair in the database.
@@ -81,9 +94,47 @@ Alias for C<set>. Stores a key-value pair in the database.
 
 Alias for C<get>. Retrieves a value for the given key.
 
-=cut
+=head2 iterator
 
-XSLoader::load('DB::Berkeley', $VERSION);
+    my $iter = $db->iterator;
+
+Returns a L<DB::Berkeley::Iterator> object which can be used to iterate over
+all key/value pairs in the database.
+
+This allows you to write iterator-style loops:
+
+    my $iter = $db->iterator;
+
+    while (my $pair = $iter->each()) {
+        my ($key, $value) = @{$pair};
+        print "Key: $key, Value: $value\n";
+    }
+
+You can reset the iterator using:
+
+    $iter->iterator_reset();
+
+Note that calling C<each()> or other iteration methods directly on the C<$db> object
+will use an internal cursor that is separate from the object returned by C<iterator()>.
+
+This is especially useful for nested iteration or concurrent traversal contexts.
+
+=head2 sync
+
+    $db->sync();
+
+Flushes all pending writes to disk.
+Useful for ensuring durability between critical updates.
+
+Returns true on success.
+Croaks on error.
+
+=head2 sync_on_put
+
+    $db->sync_on_put(1);     # Enable syncing on put
+    my $flag = $db->sync_on_put();  # Check current status
+
+Get or set whether C<put()> operations immediately flush to disk via C<sync()>.
 
 =head1 AUTHOR
 
@@ -158,4 +209,3 @@ The licence terms of this software are as follows:
 =cut
 
 1;
-
